@@ -1,4 +1,4 @@
-#!/usr/bin/perl -I./lib/
+#!/usr/bin/perl -I./blib/lib -I./blib/arch
 
 use Test::Harness;
 
@@ -7,6 +7,8 @@ runtests(
     't/core/expression.t',
     't/core/loader.t',
     't/core/template.t',
+    't/core/utils.t',
+    't/expression/logic.t',
     't/expression/in.t',
     't/expression/eq.t',
     't/expression/defined.t',
@@ -37,6 +39,7 @@ runtests(
     't/filter/ljust.t',
     't/filter/lower.t',
     't/filter/make_list.t',
+    't/filter/numberformat.t',
     't/filter/phone2numeric.t',
     't/filter/pluralize.t',
     't/filter/pluralize_ru.t',
@@ -90,4 +93,5 @@ runtests(
     't/tag/verbatim.t',
     't/tag/widthratio.t',
     't/tag/with.t',
+    't/xs/spaceless.t',
 );
\ No newline at end of file
